use Test::More tests => 1;

BEGIN {
use_ok( 'HTML::FormHandler::Field::Date::Infinite' );
}

diag( "Testing HTML::FormHandler::Field::Date::Infinite $HTML::FormHandler::Field::Date::Infinite::VERSION" );
